==> teamapps-ui-dsl-0.9.90-sources.jar: org/teamapps/dto/generate/StGroupFactory.java <==
/*-
 * ========================LICENSE_START=================================
 * TeamApps
 * ---
 * Copyright (C) 2014 - 2021 TeamApps.org
 * ---
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =========================LICENSE_END==================================
 */
package org.teamapps.dto.generate;

import org.stringtemplate.v4.STGroupFile;
import org.teamapps.dto.TeamAppsDtoParser;
import org.teamapps.dto.generate.adapter.ClassDeclarationContextModelAdaptor;
import org.teamapps.dto.generate.adapter.CommandDeclarationContextModelAdaptor;
import org.teamapps.dto.generate.adapter.EnumDeclarationContextModelAdapter;
import org.teamapps.dto.generate.adapter.EventDeclarationContextModelAdaptor;
import org.teamapps.dto.generate.adapter.InterfaceDeclarationContextModelAdaptor;
import org.teamapps.dto.generate.adapter.PojoModelAdaptor;
import org.teamapps.dto.generate.adapter.PropertyDeclarationContextModelAdaptor;
import org.teamapps.dto.generate.adapter.SubCommandDeclarationContextModelAdaptor;
import org.teamapps.dto.generate.adapter.SubEventDeclarationContextModelAdaptor;
import org.teamapps.dto.generate.adapter.TypeContextModelAdaptor;

public class StGroupFactory {
    public static STGroupFile createStGroup(
            String templateFileResourcePath,
            TeamAppsDtoModel model
    ) {
        STGroupFile stGroup = new STGroupFile(StGroupFactory.class.getResource(templateFileResourcePath), "UTF-8", '<', '>');
        stGroup.registerRenderer(String.class, new StringRenderer());

        stGroup.registerModelAdaptor(Object.class, new PojoModelAdaptor());
        stGroup.registerModelAdaptor(TeamAppsDtoParser.ClassDeclarationContext.class, new ClassDeclarationContextModelAdaptor(model));
        stGroup.registerModelAdaptor(TeamAppsDtoParser.InterfaceDeclarationContext.class, new InterfaceDeclarationContextModelAdaptor(model));
        stGroup.registerModelAdaptor(TeamAppsDtoParser.EnumDeclarationContext.class, new EnumDeclarationContextModelAdapter());
        stGroup.registerModelAdaptor(TeamAppsDtoParser.EventDeclarationContext.class, new EventDeclarationContextModelAdaptor(model));
        stGroup.registerModelAdaptor(TeamAppsDtoParser.CommandDeclarationContext.class, new CommandDeclarationContextModelAdaptor(model));
        stGroup.registerModelAdaptor(TeamAppsDtoParser.SubEventDeclarationContext.class, new SubEventDeclarationContextModelAdaptor(model));
        stGroup.registerModelAdaptor(TeamAppsDtoParser.SubCommandDeclarationContext.class, new SubCommandDeclarationContextModelAdaptor(model));
        stGroup.registerModelAdaptor(TeamAppsDtoParser.PropertyDeclarationContext.class, new PropertyDeclarationContextModelAdaptor());
        stGroup.registerModelAdaptor(TeamAppsDtoParser.TypeContext.class, new TypeContextModelAdaptor(model));
        return stGroup;
    }
}

==> teamapps-ui-dsl-0.9.128-sources.jar: org/teamapps/dto/generate/StGroupFactory.java <==
/*-
 * ========================LICENSE_START=================================
 * TeamApps
 * ---
 * Copyright (C) 2014 - 2021 TeamApps.org
 * ---
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =========================LICENSE_END==================================
 */
package org.teamapps.dto.generate;

import org.stringtemplate.v4.STGroupFile;
import org.teamapps.dto.TeamAppsDtoParser;
import org.teamapps.dto.generate.adapter.*;

public class StGroupFactory {
    public static STGroupFile createStGroup(
            String templateFileResourcePath,
            TeamAppsDtoModel model
    ) {
        STGroupFile stGroup = new STGroupFile(StGroupFactory.class.getResource(templateFileResourcePath), "UTF-8", '<', '>');
        stGroup.registerRenderer(String.class, new StringRenderer());

        stGroup.registerModelAdaptor(Object.class, new PojoModelAdaptor());
        stGroup.registerModelAdaptor(TeamAppsDtoParser.ClassDeclarationContext.class, new ClassDeclarationContextModelAdaptor(model));
        stGroup.registerModelAdaptor(TeamAppsDtoParser.InterfaceDeclarationContext.class, new InterfaceDeclarationContextModelAdaptor(model));
        stGroup.registerModelAdaptor(TeamAppsDtoParser.EnumDeclarationContext.class, new EnumDeclarationContextModelAdapter());
        stGroup.registerModelAdaptor(TeamAppsDtoParser.EventDeclarationContext.class, new EventDeclarationContextModelAdaptor(model));
        stGroup.registerModelAdaptor(TeamAppsDtoParser.CommandDeclarationContext.class, new CommandDeclarationContextModelAdaptor(model));
        stGroup.registerModelAdaptor(TeamAppsDtoParser.QueryDeclarationContext.class, new QueryDeclarationContextModelAdaptor(model));
        stGroup.registerModelAdaptor(TeamAppsDtoParser.PropertyDeclarationContext.class, new PropertyDeclarationContextModelAdaptor());
        stGroup.registerModelAdaptor(TeamAppsDtoParser.TypeContext.class, new TypeContextModelAdaptor(model));
        return stGroup;
    }
}
